==> haskell-servant-0.16.1-11-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-servant.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: servant
version: 0.16.1
id: servant-0.16.1-LO6E5Y5dagMB069nsfIDP9
key: servant-0.16.1-LO6E5Y5dagMB069nsfIDP9
license: BSD-3-Clause
copyright: 2014-2016 Zalora South East Asia Pte Ltd, 2016-2019 Servant Contributors
maintainer: haskell-servant-maintainers@googlegroups.com
author: Servant Contributors
homepage: http://docs.servant.dev/
synopsis: A family of combinators for defining webservices APIs
description:
    A family of combinators for defining webservices APIs and serving them
    .
    You can learn about the basics in the <http://docs.servant.dev/en/stable/tutorial/index.html tutorial>.
    .
    <https://github.com/haskell-servant/servant/blob/master/servant/CHANGELOG.md CHANGELOG>
category: Servant, Web
abi: 60844f052151bead87783d4eed80dd07
exposed: True
exposed-modules:
    Servant.API Servant.API.Alternative Servant.API.BasicAuth
    Servant.API.Capture Servant.API.ContentTypes
    Servant.API.Description Servant.API.Empty
    Servant.API.Experimental.Auth Servant.API.Generic
    Servant.API.Header Servant.API.HttpVersion
    Servant.API.Internal.Test.ComprehensiveAPI Servant.API.IsSecure
    Servant.API.Modifiers Servant.API.QueryParam Servant.API.Raw
    Servant.API.RemoteHost Servant.API.ReqBody
    Servant.API.ResponseHeaders Servant.API.Stream Servant.API.Sub
    Servant.API.TypeLevel Servant.API.Vault Servant.API.Verbs
    Servant.API.WithNamedContext Servant.Links
    Servant.Test.ComprehensiveAPI Servant.Types.SourceT
    Servant.Utils.Links
import-dirs: /usr/lib/ghc-8.6.5/site-local/servant-0.16.1
library-dirs: /usr/lib/ghc-8.6.5/site-local/servant-0.16.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/servant-0.16.1
hs-libraries: HSservant-0.16.1-LO6E5Y5dagMB069nsfIDP9
depends:
    QuickCheck-2.13.2-52gUk4jYsn5ItHsbXhjyg4
    aeson-1.4.4.0-4k9y4wJphux8r1uVsrGHfo
    attoparsec-0.13.2.2-DdvIu9rGyq0BlJd07CKvqt base-4.12.0.0
    base-compat-0.10.5-FRXoAxOVtbG2qLNIZm1tTr
    bifunctors-5.5.4-Kc3GWvpiUGKFKiRvcXJB6c bytestring-0.10.8.2
    case-insensitive-1.2.1.0-L7BR5PaOPZy5cAHpLYQKhk deepseq-1.4.4.0
    http-api-data-0.4.1-ECZvIII9ExuFRM5hcBUejQ
    http-media-0.8.0.0-L25zQqkU26CA7yE3vl2O05
    http-types-0.12.3-3Nd2h8pfDaM3STPvc3OlR8
    mmorph-1.1.3-FfwptCv2VaAjI2vq7vsWW mtl-2.2.2
    network-uri-2.6.1.0-K75fCYvLQE41EntOQ30cqK
    singleton-bool-0.1.5-ILc7I2ZiylMBjb8V7CUi6W
    string-conversions-0.4.0.1-LtuUK6ZkUgfAmoIrlRp9AZ
    tagged-0.8.6-AoE7RQX12AwJxLvAxGYxtP text-1.2.3.1
    transformers-0.5.6.2 vault-0.3.1.3-29KRmbkaBkX9f9zmYZ8lk1
haddock-interfaces: /usr/share/doc/haskell-servant/html/servant.haddock
haddock-html: /usr/share/doc/haskell-servant/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-servant-0.16.1-12-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-servant.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: servant
version: 0.16.1
id: servant-0.16.1-9qAkiCgJjnWEbTgYZsaHw1
key: servant-0.16.1-9qAkiCgJjnWEbTgYZsaHw1
license: BSD-3-Clause
copyright: 2014-2016 Zalora South East Asia Pte Ltd, 2016-2019 Servant Contributors
maintainer: haskell-servant-maintainers@googlegroups.com
author: Servant Contributors
homepage: http://docs.servant.dev/
synopsis: A family of combinators for defining webservices APIs
description:
    A family of combinators for defining webservices APIs and serving them
    .
    You can learn about the basics in the <http://docs.servant.dev/en/stable/tutorial/index.html tutorial>.
    .
    <https://github.com/haskell-servant/servant/blob/master/servant/CHANGELOG.md CHANGELOG>
category: Servant, Web
abi: 4bd521d4d0b1f607fcb0072e419e73f5
exposed: True
exposed-modules:
    Servant.API Servant.API.Alternative Servant.API.BasicAuth
    Servant.API.Capture Servant.API.ContentTypes
    Servant.API.Description Servant.API.Empty
    Servant.API.Experimental.Auth Servant.API.Generic
    Servant.API.Header Servant.API.HttpVersion
    Servant.API.Internal.Test.ComprehensiveAPI Servant.API.IsSecure
    Servant.API.Modifiers Servant.API.QueryParam Servant.API.Raw
    Servant.API.RemoteHost Servant.API.ReqBody
    Servant.API.ResponseHeaders Servant.API.Stream Servant.API.Sub
    Servant.API.TypeLevel Servant.API.Vault Servant.API.Verbs
    Servant.API.WithNamedContext Servant.Links
    Servant.Test.ComprehensiveAPI Servant.Types.SourceT
    Servant.Utils.Links
import-dirs: /usr/lib/ghc-8.6.5/site-local/servant-0.16.1
library-dirs: /usr/lib/ghc-8.6.5/site-local/servant-0.16.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/servant-0.16.1
hs-libraries: HSservant-0.16.1-9qAkiCgJjnWEbTgYZsaHw1
depends:
    QuickCheck-2.13.2-KEVEjFnAQhp2P6vBjviJXi
    aeson-1.4.4.0-HZF4dQ7ymfT471uy0aBwyJ
    attoparsec-0.13.2.2-JtccVfLzqCgD0Y1SyaKt8t base-4.12.0.0
    base-compat-0.10.5-FRXoAxOVtbG2qLNIZm1tTr
    bifunctors-5.5.4-9Tb0bkUz5VW2Ucg8P8K6vJ bytestring-0.10.8.2
    case-insensitive-1.2.1.0-L7BR5PaOPZy5cAHpLYQKhk deepseq-1.4.4.0
    http-api-data-0.4.1-24gDk8mVmZmEhHsrhXyVOb
    http-media-0.8.0.0-L25zQqkU26CA7yE3vl2O05
    http-types-0.12.3-4mvqCFA58Pd9Ot84cA11d5
    mmorph-1.1.3-FfwptCv2VaAjI2vq7vsWW mtl-2.2.2
    network-uri-2.6.1.0-K75fCYvLQE41EntOQ30cqK
    singleton-bool-0.1.5-ILc7I2ZiylMBjb8V7CUi6W
    string-conversions-0.4.0.1-LtuUK6ZkUgfAmoIrlRp9AZ
    tagged-0.8.6-AoE7RQX12AwJxLvAxGYxtP text-1.2.3.1
    transformers-0.5.6.2 vault-0.3.1.3-DmOQCG854Cn3Hyqd39Y0Gb
haddock-interfaces: /usr/share/doc/haskell-servant/html/servant.haddock
haddock-html: /usr/share/doc/haskell-servant/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
